communication_channels library

Classes

ChannelFunction<Ret extends TypeSync?>
Base class for all channel functions
ChannelFunctionConfig<FUN extends ChannelFunction<TypeSync?>>
ChannelMessage
The base Class for Messages that are sent through Channels
ChannelNotification
ChannelResult<T extends Object?>
the result object the will be returned of message.
ChannelsDefinitions
ChannelType
ComProvider<S extends ProviderSender>
ProviderSender
SocketComProvider
SocketSender
ThisChannel

Enums

ChannelEvent
ChannelMessageType
The type of Message
ChannelResultType
possible results when calling a message.

Properties

neverFuture Future<Object?>
final

Typedefs

ChannelResultGenType<T extends Object?> = Future<ChannelResult<T>>
ResultErrorType = ({String err, String stacktrace})
SentChannelMessageType = Map<String, dynamic>
TypeAsync<T extends Object?> = Future<T>
TypeSync = Object?