ChannelType class
- Available extensions
Constructors
-
ChannelType({required int code, required ComProvider<
ProviderSender> provider, String? debugName})
Properties
- code → int
-
final
- debugName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ping(
) → Future< bool> -
Available on ChannelType, provided by the ChannelTypeExtension extension
-
toString(
) → String -
A string representation of this object.
override
-
waitUntilStart(
[Duration? timeout, bool pingFirst = true]) → Future< bool> -
Available on ChannelType, provided by the ChannelTypeExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
int code) → ChannelType